@@ -77,26 +77,14 @@ class File:
         t = None
 
         if self.encode != None:
-            # t = f.read().decode(self.encode)
             f = open(self.fileName, "rb")
             t = f.read()
+            t = t.decode(self.encode)
             f.close()
-
-            # with open(self.fileName, "rb") as binary_file:
-            #     # Read the whole file at once
-            #     f = binary_file.read()
-
-            # with open(self.fileName, "rb") as f:
-            #     byte = f.read(1)
-            #         while byte:
-            #         # Do stuff with byte.
-            #         byte = f.read(1)
-
         else:
             f = open(self.fileName)
             t = f.read()
             f.close()
-        # f.close
         return t
 
     def print(self):
